package com.jjt.rz.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.rz.domain.TwinDeviceType;
import com.jjt.rz.domain.TwinDeviceTypeData;

/**
 * 设备类型管理Mapper接口
 * 
 * @author wukai
 * @date 2025-05-21
 */
public interface TwinDeviceTypeMapper extends BaseMapper<TwinDeviceType>
{
    /**
     * 查询设备类型管理
     * 
     * @param typeId 设备类型管理主键
     * @return 设备类型管理
     */
    public TwinDeviceType selectTwinDeviceTypeByTypeId(Long typeId);

    /**
     * 查询设备类型管理列表
     * 
     * @param twinDeviceType 设备类型管理
     * @return 设备类型管理集合
     */
    public List<TwinDeviceType> selectTwinDeviceTypeList(TwinDeviceType twinDeviceType);

    /**
     * 新增设备类型管理
     * 
     * @param twinDeviceType 设备类型管理
     * @return 结果
     */
    public int insertTwinDeviceType(TwinDeviceType twinDeviceType);

    /**
     * 修改设备类型管理
     * 
     * @param twinDeviceType 设备类型管理
     * @return 结果
     */
    public int updateTwinDeviceType(TwinDeviceType twinDeviceType);

    /**
     * 删除设备类型管理
     * 
     * @param typeId 设备类型管理主键
     * @return 结果
     */
    public int deleteTwinDeviceTypeByTypeId(Long typeId);

    /**
     * 批量删除设备类型管理
     * 
     * @param typeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinDeviceTypeByTypeIds(Long[] typeIds);

    /**
     * 批量删除设备类型数据管理
     * 
     * @param typeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinDeviceTypeDataByTypeIds(Long[] typeIds);
    
    /**
     * 批量新增设备类型数据管理
     * 
     * @param twinDeviceTypeDataList 设备类型数据管理列表
     * @return 结果
     */
    public int batchTwinDeviceTypeData(List<TwinDeviceTypeData> twinDeviceTypeDataList);
    

    /**
     * 通过设备类型管理主键删除设备类型数据管理信息
     * 
     * @param typeId 设备类型管理ID
     * @return 结果
     */
    public int deleteTwinDeviceTypeDataByTypeId(Long typeId);
}
